@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl =
 [
-    [ "UnoControl", "servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html#a2ea5cb8677fdcc23bbd807328ef59dd0", null ],
+    [ "com::sun::star::awt::UnoControl", "servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html#a2ea5cb8677fdcc23bbd807328ef59dd0", null ],
     [ "ComponentUrl", "servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html#a893e49a7ac55a364f59d62e6aabb9c03", null ],
     [ "Frame", "servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html#a4fb809148946fff0aaefefc4422bc976", null ]
 ];
\ No newline at end of file
